pro msok_poi_copy, noftp=noftp
;+
;   Name: msok_poi_copy
;
;   Purpose: copy MSO Ca-K FITS (POI)
;
;   25-sep-1995 (SLF) First Light optional image
;   16-apr-1995 (SLF) Get FITS from POI
;   17-apr-1995 (SLF) add /noftp (therfore kluging logic...)
;   20-may-1998 (PGS) changed name string from P??????.????.fts 
;                     to P??????_????.fts to stop crashes.
;-
ftpit=1-keyword_set(noftp)

msokenv=get_logenv('DIR_GBO_SC')
if ftpit then begin 
   ftpit=keyword_set(ftpit)
;  ----------------------------
;  remote ftp information
   mso_ip="akala.ifa.hawaii.edu"
   subdir="pub/kline"
;  ----------------------------
; 
   ftp_copy,mso_ip, subdir=subdir, /list,dirlist=dirlist,/anon
   if n_elements(dirlist) eq 0 then begin
      message,/info,"Problem in FTP connection..."
      return
   endif 

   good = where(strlen(dirlist) eq 70,gcnt) 
   directory=str2cols(dirlist(good))
   fnames=strtrim(reform(directory(8,*)),2)
   which=wc_where(fnames,'P??????_????.fts')	; POI C-KII line
   fnames=fnames(which)
endif else begin
   files=file_list('$DIR_GBO_SC','P??????_????.fts')
   if files(0) eq '' then begin
      message,/info,"/noftp set and no files to rename"
      return
   endif
   break_file,files,logs,path,fnames,exts,vers
   fnames=fnames + exts
   
endelse
fids=strmid(fnames,1,11)

; assumption - only one per day
msokfiles='gmk' + fids
outdirs=find_gbo_dir(msokfiles)
msobest=concat_dir(outdirs,msokfiles)

if ftpit then need=where(1-file_exist(msobest),ncnt) else $
   need=lindgen(n_elements(fnames))

if need(0) ne -1 then begin
   if ftpit then begin 
      message,/info,"Need " + strtrim(ncnt,2) + " MSO POI Kline files..."
;     get the files
      ftp_copy,fnames(need), mso_ip, subdir, /anon, /get, outdir=msokenv
   endif
;  rename the files
   newfiles=concat_dir(msokenv,fnames(need))
   for i=0,n_elements(newfiles)-1 do  begin
      if file_exist(newfiles(i)) then begin
         data=rfits(newfiles(i),head=head)
         oname=msobest(need(i))
         message,/info,"Converting "  + newfiles(i) + " to " + oname
         odisk=cir_mask(data,fxpar(head,'CRPIX1'),fxpar(head,'CRPIX2'),$
              fxpar(head,'RADIUS'),/outside)
         data(odisk)=0.				; mask off-sun area
         fxaddpar,head,'COMMENT','Masked version of MEES file: ' + fnames(i)
         fxaddpar,head,'COMMENT','Roll Corrected (Solar N. is up)'
         writefits,oname,data,head
         file_delete,newfiles(i)
      endif else begin
	 message,/info,"Problem getting MSOK file: "+ newfiles(i)  
      endelse
   endfor

   if n_elements(head) ne 0 then begin		; make a genx file
      lastmso=get1gbo('gmk',head=head,dattim=msotim)
      savegen, lastmso, text=["Last MSOK Image", fmt_tim(msotim)], $
         file=concat_dir(get_logenv('DIR_SHOWPIX_SC'),'Last_MSOK.genx')
   endif
endif else message,/info,"Have all the MSO Kline files already..."

return
end
